@@ -204,7 +204,7 @@ spi_dec_plat_emit_modifier_event (SpiDEController *controller, guint prev_mask,
   SpiDEControllerClass *klass;
   klass = SPI_DEVICE_EVENT_CONTROLLER_GET_CLASS (controller);
   if (klass->plat.emit_modifier_event)
-    return klass->plat.emit_modifier_event (controller, prev_mask, current_mask);
+    klass->plat.emit_modifier_event (controller, prev_mask, current_mask);
 }
 
 static void
@@ -216,7 +216,7 @@ spi_dec_plat_generate_mouse_event (SpiDEController *controller,
   SpiDEControllerClass *klass;
   klass = SPI_DEVICE_EVENT_CONTROLLER_GET_CLASS (controller);
   if (klass->plat.generate_mouse_event)
-    return klass->plat.generate_mouse_event (controller, x, y, eventName);
+    klass->plat.generate_mouse_event (controller, x, y, eventName);
 }
 
 DBusMessage *
